@@ -87,9 +87,11 @@ class Directories:
     @staticmethod
     def from_config():
         """Returns Localstack directory paths from the config/environment variables defined by the config."""
+        # Note that the entries should be unique, as further downstream in docker_utils.py we're removing
+        # duplicate host paths in the volume mounts via `dict(mount_volumes)`.
         return Directories(
             static_libs=INSTALL_DIR_INFRA,
-            var_libs=TMP_FOLDER,  # TODO: add variable
+            var_libs=VAR_LIBS_DIR,
             cache=CACHE_DIR,
             tmp=TMP_FOLDER,  # TODO: should inherit from root value for /var/lib/localstack (e.g., MOUNT_ROOT)
             functions=HOST_TMP_FOLDER,  # TODO: rename variable/consider a volume
@@ -114,13 +116,19 @@ class Directories:
             or "/var/lib/localstack/var_libs"
         )
         cache = os.environ.get("CONTAINER_CACHE_FOLDER", "").strip() or "/var/lib/localstack/cache"
+        tmp = (
+            os.environ.get("CONTAINER_TMP_FOLDER", "").strip() or "/tmp/localstack"
+        )  # TODO: discuss movement to /var/lib/localstack/tmp
+        data_dir = os.environ.get("CONTAINER_DATA_DIR_FOLDER", "").strip() or (
+            DATA_DIR if in_docker() else "/tmp/localstack_data"
+        )  # TODO: move to /var/lib/localstack/data
         return Directories(
             static_libs=INSTALL_DIR_INFRA,
             var_libs=var_libs,
             cache=cache,
-            tmp=TMP_FOLDER,  # TODO: move to /var/lib/localstack/tmp - or /tmp/localstack
+            tmp=tmp,
             functions=HOST_TMP_FOLDER,  # TODO: move to /var/lib/localstack/tmp
-            data=DATA_DIR,  # TODO: move to /var/lib/localstack/data
+            data=data_dir,
             config=None,  # config directory is host-only
             logs="/var/lib/localstack/logs",
             init="/docker-entrypoint-initaws.d",
@@ -293,8 +301,10 @@ if TMP_FOLDER.startswith("/var/folders/") and os.path.exists("/private%s" % TMP_
 # temporary folder of the host (required when running in Docker). Fall back to local tmp folder if not set
 HOST_TMP_FOLDER = os.environ.get("HOST_TMP_FOLDER", TMP_FOLDER)
 
-# ephemeral cache dir that persists over reboots
+# ephemeral cache dir that persists across reboots
 CACHE_DIR = os.environ.get("CACHE_DIR", os.path.join(TMP_FOLDER, "cache")).strip()
+# libs cache dir that persists across reboots
+VAR_LIBS_DIR = os.environ.get("VAR_LIBS_DIR", os.path.join(TMP_FOLDER, "var_libs")).strip()
 
 # whether to enable verbose debug logging
 LS_LOG = eval_log_type("LS_LOG")
@@ -574,6 +584,19 @@ ES_ENDPOINT_STRATEGY = os.environ.get("ES_ENDPOINT_STRATEGY", "").strip() or "do
 # Whether to start one cluster per domain (default), or multiplex domains to a single clusters
 ES_MULTI_CLUSTER = is_env_not_false("ES_MULTI_CLUSTER")
 
+# URL to a custom opensearch backend cluster. If this is set to a valid URL, then localstack will not create
+# opensearch cluster instances, but instead forward all domains to the given backend.
+OPENSEARCH_CUSTOM_BACKEND = os.environ.get("OPENSEARCH_CUSTOM_BACKEND", "").strip()
+
+# Strategy used when creating opensearch domain endpoints routed through the edge proxy
+# valid values: domain | path
+OPENSEARCH_ENDPOINT_STRATEGY = (
+    os.environ.get("OPENSEARCH_ENDPOINT_STRATEGY", "").strip() or "domain"
+)
+
+# Whether to start one openseasrch cluster per domain (default), or multiplex opensearch domains to a single clusters
+OPENSEARCH_MULTI_CLUSTER = is_env_not_false("OPENSEARCH_MULTI_CLUSTER")
+
 # list of environment variable names used for configuration.
 # Make sure to keep this in sync with the above!
 # Note: do *not* include DATA_DIR in this list, as it is treated separately
@@ -633,6 +656,7 @@ CONFIG_ENV_VARS = [
     "S3_SKIP_SIGNATURE_VALIDATION",
     "SERVICES",
     "SKIP_INFRA_DOWNLOADS",
+    "SQS_PORT_EXTERNAL",
     "STEPFUNCTIONS_LAMBDA_ENDPOINT",
     "SYNCHRONOUS_API_GATEWAY_EVENTS",
     "SYNCHRONOUS_DYNAMODB_EVENTS",
@@ -752,12 +776,15 @@ def populate_configs(service_ports=None):
 
 
 def service_port(service_key):
+    service_key = service_key.lower()
     if FORWARD_EDGE_INMEM:
         if service_key == "elasticsearch":
             # TODO Elasticsearch domains are a special case - we do not want to route them through
             #  the edge service, as that would require too many route mappings. In the future, we
             #  should integrate them with the port range for external services (4510-4530)
             return SERVICE_PORTS.get(service_key, 0)
+        if service_key == "sqs" and SQS_PORT_EXTERNAL:
+            return SQS_PORT_EXTERNAL
         return get_edge_port_http()
     return SERVICE_PORTS.get(service_key, 0)
 
